aboutsummaryrefslogtreecommitdiff
path: root/backends/fs/psp/psp-fs-factory.h
diff options
context:
space:
mode:
authorMax Horn2008-02-23 19:01:12 +0000
committerMax Horn2008-02-23 19:01:12 +0000
commit80d55b0388ef5883202fa13035115d79046b3072 (patch)
treec669cb6eaeb6bc69217df084525f77ee2745f72f /backends/fs/psp/psp-fs-factory.h
parent1cf9fc944a8488e928da49208118a32ea10c3c62 (diff)
downloadscummvm-rg350-80d55b0388ef5883202fa13035115d79046b3072.tar.gz
scummvm-rg350-80d55b0388ef5883202fa13035115d79046b3072.tar.bz2
scummvm-rg350-80d55b0388ef5883202fa13035115d79046b3072.zip
Renamed AbstractFilesystemFactory to FilesystemFactory
svn-id: r30935
Diffstat (limited to 'backends/fs/psp/psp-fs-factory.h')
-rw-r--r--backends/fs/psp/psp-fs-factory.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/backends/fs/psp/psp-fs-factory.h b/backends/fs/psp/psp-fs-factory.h
index 143b2ce684..ffa934755f 100644
--- a/backends/fs/psp/psp-fs-factory.h
+++ b/backends/fs/psp/psp-fs-factory.h
@@ -26,14 +26,14 @@
#define PSP_FILESYSTEM_FACTORY_H
#include "common/singleton.h"
-#include "backends/fs/abstract-fs-factory.h"
+#include "backends/fs/fs-factory.h"
/**
* Creates PSPFilesystemNode objects.
*
* Parts of this class are documented in the base interface class, AbstractFilesystemFactory.
*/
-class PSPFilesystemFactory : public AbstractFilesystemFactory, public Common::Singleton<PSPFilesystemFactory> {
+class PSPFilesystemFactory : public FilesystemFactory, public Common::Singleton<PSPFilesystemFactory> {
public:
typedef Common::String String;
@@ -26,14 +26,14 @@
* Creates PSPFilesystemNode objects.
*
- * Parts of this class are documented in the base interface class, AbstractFilesystemFactory.
+ * Parts of this class are documented in the base interface class, FilesystemFactory.
*/